@@ -6,26 +6,40 @@ from __future__ import absolute_import
 from odahuflow.sdk.models.api_backend_config import APIBackendConfig
 from odahuflow.sdk.models.api_config import APIConfig
 from odahuflow.sdk.models.api_local_backend_config import APILocalBackendConfig
+from odahuflow.sdk.models.algorithm_source import AlgorithmSource
 from odahuflow.sdk.models.auth_config import AuthConfig
+from odahuflow.sdk.models.batch_config import BatchConfig
 from odahuflow.sdk.models.claims import Claims
 from odahuflow.sdk.models.common_config import CommonConfig
 from odahuflow.sdk.models.config import Config
 from odahuflow.sdk.models.connection import Connection
 from odahuflow.sdk.models.connection_config import ConnectionConfig
+from odahuflow.sdk.models.connection_reference import ConnectionReference
 from odahuflow.sdk.models.connection_spec import ConnectionSpec
 from odahuflow.sdk.models.connection_status import ConnectionStatus
 from odahuflow.sdk.models.data_binding_dir import DataBindingDir
+from odahuflow.sdk.models.deployment_event import DeploymentEvent
 from odahuflow.sdk.models.edge_config import EdgeConfig
 from odahuflow.sdk.models.environment_variable import EnvironmentVariable
 from odahuflow.sdk.models.external_url import ExternalUrl
+from odahuflow.sdk.models.feedback_model_feedback import FeedbackModelFeedback
 from odahuflow.sdk.models.feedback_model_feedback_request import FeedbackModelFeedbackRequest
-from odahuflow.sdk.models.feedback_model_feedback_response import FeedbackModelFeedbackResponse
 from odahuflow.sdk.models.http_result import HTTPResult
+from odahuflow.sdk.models.inference_job import InferenceJob
+from odahuflow.sdk.models.inference_job_spec import InferenceJobSpec
+from odahuflow.sdk.models.inference_job_status import InferenceJobStatus
+from odahuflow.sdk.models.inference_service import InferenceService
+from odahuflow.sdk.models.inference_service_spec import InferenceServiceSpec
+from odahuflow.sdk.models.inference_service_status import InferenceServiceStatus
+from odahuflow.sdk.models.inference_service_triggers import InferenceServiceTriggers
 from odahuflow.sdk.models.input_data_binding_dir import InputDataBindingDir
 from odahuflow.sdk.models.jwks import JWKS
 from odahuflow.sdk.models.json_schema import JsonSchema
 from odahuflow.sdk.models.k8s_packager import K8sPackager
 from odahuflow.sdk.models.k8s_trainer import K8sTrainer
+from odahuflow.sdk.models.latest_deployment_events import LatestDeploymentEvents
+from odahuflow.sdk.models.latest_route_events import LatestRouteEvents
+from odahuflow.sdk.models.local_model_source import LocalModelSource
 from odahuflow.sdk.models.model_deployment import ModelDeployment
 from odahuflow.sdk.models.model_deployment_config import ModelDeploymentConfig
 from odahuflow.sdk.models.model_deployment_istio_config import ModelDeploymentIstioConfig
@@ -34,6 +48,7 @@ from odahuflow.sdk.models.model_deployment_spec import ModelDeploymentSpec
 from odahuflow.sdk.models.model_deployment_status import ModelDeploymentStatus
 from odahuflow.sdk.models.model_deployment_target import ModelDeploymentTarget
 from odahuflow.sdk.models.model_identity import ModelIdentity
+from odahuflow.sdk.models.model_meta import ModelMeta
 from odahuflow.sdk.models.model_packaging import ModelPackaging
 from odahuflow.sdk.models.model_packaging_config import ModelPackagingConfig
 from odahuflow.sdk.models.model_packaging_result import ModelPackagingResult
@@ -43,11 +58,13 @@ from odahuflow.sdk.models.model_property import ModelProperty
 from odahuflow.sdk.models.model_route import ModelRoute
 from odahuflow.sdk.models.model_route_spec import ModelRouteSpec
 from odahuflow.sdk.models.model_route_status import ModelRouteStatus
+from odahuflow.sdk.models.model_source import ModelSource
 from odahuflow.sdk.models.model_training import ModelTraining
 from odahuflow.sdk.models.model_training_config import ModelTrainingConfig
 from odahuflow.sdk.models.model_training_spec import ModelTrainingSpec
 from odahuflow.sdk.models.model_training_status import ModelTrainingStatus
 from odahuflow.sdk.models.node_pool import NodePool
+from odahuflow.sdk.models.object_storage import ObjectStorage
 from odahuflow.sdk.models.operator_config import OperatorConfig
 from odahuflow.sdk.models.packager_config import PackagerConfig
 from odahuflow.sdk.models.packager_target import PackagerTarget
@@ -55,8 +72,11 @@ from odahuflow.sdk.models.packaging_integration import PackagingIntegration
 from odahuflow.sdk.models.packaging_integration_spec import PackagingIntegrationSpec
 from odahuflow.sdk.models.packaging_integration_status import PackagingIntegrationStatus
 from odahuflow.sdk.models.parameter import Parameter
+from odahuflow.sdk.models.predictor_webhook_trigger import PredictorWebhookTrigger
+from odahuflow.sdk.models.remote_model_source import RemoteModelSource
 from odahuflow.sdk.models.resource_list import ResourceList
 from odahuflow.sdk.models.resource_requirements import ResourceRequirements
+from odahuflow.sdk.models.route_event import RouteEvent
 from odahuflow.sdk.models.schema import Schema
 from odahuflow.sdk.models.service_catalog import ServiceCatalog
 from odahuflow.sdk.models.target import Target
@@ -68,4 +88,5 @@ from odahuflow.sdk.models.trainer_config import TrainerConfig
 from odahuflow.sdk.models.training_result import TrainingResult
 from odahuflow.sdk.models.user_config import UserConfig
 from odahuflow.sdk.models.user_info import UserInfo
+from odahuflow.sdk.models.vcs import VCS
 from odahuflow.sdk.models.vault import Vault
